@@ -15,6 +15,7 @@
 
 #ifdef _WIN32
 
+#include <objbase.h>
 #include <initguid.h>
 #include <tchar.h>
 #include <io.h>
@@ -57,13 +58,6 @@ EXTERN int my_debug( const char *fmt, ... );
 #define _debug my_debug
 #endif
 
-#ifdef _WIN32
-#undef vsnprintf
-#define vsnprintf _vsnprintf
-#undef snprintf
-#define snprintf _snprintf
-#endif
-
 #undef BYTE
 #define BYTE unsigned char
 #undef WORD
@@ -221,6 +215,12 @@ struct sockaddr_un {
 	char						sun_path[108];			/* pathname */
 };
 
+#ifdef SC_OLDNET
+struct in6_addr {
+	uint8_t						s6_addr[16];
+};
+#endif
+
 #else /* POSIX */
 
 #define SOCKET_ERROR			-1
